function [reconData, size, bitrate] = func_simpleQuantizer(data, quantStep)
%% a simple encode that does two things:
%    1. quantizaton
%    2. entropy calculation
%  Last modified by Chau-Wai Wong on 12/5/2015
%
%  Copyright (c) 2016  Chau-Wai Wong
%  Licensed under MIT License. For the full license, refer to LICENSE.txt


%% Quantization
reconData = round ( data / quantStep ) * quantStep;

%% Entropy calculation
x = data(:);
dataMin = min(x);
dataMax = max(x);

binCenter_pos = [];
binCenter_neg = [];
if dataMax < 0
    binCenter_neg = fliplr(-quantStep : -quantStep : dataMin);
elseif dataMin > 0
    binCenter_pos = 0 : quantStep : dataMax;
else
    binCenter_pos = 0 : quantStep : dataMax;
    binCenter_neg = fliplr(-quantStep : -quantStep : dataMin);
end

binCenter = [binCenter_neg binCenter_pos];

data_hist = hist(x, binCenter);
data_hist = data_hist(:); % stick to column form for any vector
data_pmf = data_hist / sum(data_hist);
data_pmf_noZero = data_pmf(data_pmf~=0);
entropy = -data_pmf_noZero' * log2(data_pmf_noZero);
size = entropy * length(x);
bitrate = entropy;
