function [distTotal, bitrateTotal, bitrateDistribution] = func_simu3(q1, q2, sourceInfo)
%% Simulation for a transform codec with baseband quantization
%  [non-predictive coding branch of Fig. 1(b)]
%  
%  Pipeline structure:
% 
%    input --> [Q1]--[iQ1]--[T]--[Q2]--[iQ2]--[T]--[Round]--[Q1]--[iQ1]--> output
%  
%  Last modified by Chau-Wai Wong in Dec. 2016
%
%  Copyright (c) 2016  Chau-Wai Wong
%  Licensed under MIT License. For the full license, refer to LICENSE.txt


%% input data generation

% tic
data = func_genJointGaussianVectors(sourceInfo);
% toc


%% 1st quantizer

data_q1_truncated = zeros(sourceInfo.vecLen, sourceInfo.count);
for d = 1 : sourceInfo.vecLen
    [data_q1_truncated(d,:), ~] = func_simpleQuantizer(data(d,:), q1);
end


%% transform and quantization (2nd quantizer)
% T = [1 1; 1 -1] / sqrt(2); % a special case for length-2
T = dct(eye(sourceInfo.vecLen));

data_q1_transformed = T * data_q1_truncated;

data_q1_quantized = zeros(sourceInfo.vecLen, sourceInfo.count);
sizePerCoef = zeros(sourceInfo.vecLen,1);
bitratePerCoef = zeros(sourceInfo.vecLen,1);
for d = 1 : sourceInfo.vecLen
    [data_q1_quantized(d,:), sizePerCoef(d), bitratePerCoef(d)] = func_simpleQuantizer(data_q1_transformed(d,:), q2);
end

data_q1q2 = T' * data_q1_quantized;


%% 1st quantizer

[data_q1q2, ~] = func_simpleQuantizer(data_q1q2, q1);


%% obtain statistics
%myDist = @(x,y) mean(abs(x(:)-y(:)));
myDist = @(x,y) mean((x(:)-y(:)).^2);

distTotal = myDist(data, data_q1q2);
bitrateTotal = mean(bitratePerCoef);
bitrateDistribution = bitratePerCoef/sum(bitratePerCoef);

